@@ -19,9 +19,9 @@ import com.sun.jdi.request.*;
 
 public class AccessWatchpointSpec extends WatchpointSpec {
     
-    public AccessWatchpointSpec(Application app, ReferenceTypeSpec refSpec,
+    public AccessWatchpointSpec(DebuggeeProcess proc, ReferenceTypeSpec refSpec,
 				String fieldName) {
-	super(app, refSpec, fieldName);
+	super(proc, refSpec, fieldName);
     }
 
     boolean resolve(ReferenceType refType) throws JDEException {
